"""Module containing classes related to the RegEx editor."""

from .regexeditorwidget import RegexEditorWidget


__all__ = ["RegexEditorWidget"]
